@@ -1,5 +1,5 @@
 package DBIx::Perlish;
-# $Id: Perlish.pm,v 1.109 2008/11/21 15:06:05 tobez Exp $
+# $Id: Perlish.pm,v 1.111 2008/12/08 12:35:14 tobez Exp $
 
 use 5.008;
 use warnings;
@@ -10,7 +10,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS $SQL @BIND_VALUES);
 require Exporter;
 use base 'Exporter';
 
-$VERSION = '0.49';
+$VERSION = '0.50';
 @EXPORT = qw(db_fetch db_select db_update db_delete db_insert sql);
 @EXPORT_OK = qw(union intersect except);
 %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
@@ -291,7 +291,7 @@ sub gen_sql
 	} else {
 		die "unsupported operation: $operation\n";
 	}
-	my (%tabs, %joins);
+	my %tabs;
 	for my $var (keys %{$S->{vars}}) {
 		$tabs{$S->{var_alias}->{$var}} =
 			$no_aliases ?
@@ -317,21 +317,23 @@ sub gen_sql
 	}
 	$sql .= $next_bit;
 	my %seentab;
-	my @joins;
+	my $joins = "";
 	for my $j ( @{$S->{joins}} ) {
 		my ($join, $tab1, $tab2, $condition) = @$j;
 		$condition = ( defined $condition) ? " on $condition" : '';
 		if ($seentab{$tab1}) {
-			push @joins, "$join join $tabs{$tab2}$condition";
+			$joins .= " " if $joins;
+			$joins .= "$join join $tabs{$tab2}$condition";
 		} else {
-			push @joins, "$tabs{$tab1} $join join $tabs{$tab2}$condition";
+			$joins .= ", " if $joins;
+			$joins .= "$tabs{$tab1} $join join $tabs{$tab2}$condition";
 		}
 		die "not sure what to do with repeated table ($tabs{$tab2}) in a join\n"
 			if $seentab{$tab2};
 		$seentab{$tab1}++;
 		$seentab{$tab2}++;
 	}
-	@joins = @joins ? (join " ", @joins) : ();
+	my @joins = $joins ? ($joins) : ();
 	$sql .= join ", ", @joins, map { $tabs{$_} } grep { !$seentab{$_} } sort keys %tabs;
 
 	my @sets     = grep { $_ ne "" } @{$S->{sets}};
@@ -385,7 +387,7 @@ DBIx::Perlish - a perlish interface to SQL databases
 
 =head1 VERSION
 
-This document describes DBIx::Perlish version 0.49
+This document describes DBIx::Perlish version 0.50
 
 
 =head1 SYNOPSIS
@@ -545,6 +547,41 @@ Examples:
     my $dbh = DBH->connect(...);
     DBIx::Perlish::init($dbh);
 
+=head3 Special treatment of the C<$dbh> variable
+
+If the user did not
+call C<init()> before issuing any of the C<db_fetch {}>,
+C<db_update {}>, C<db_delete {}> or C<db_insert {}>, those
+functions look for one special case before bailing out.
+
+Namely, they try to locate a variable C<my $dbh>, C<our $dbh>,
+or caller's package global C<$dbh>,
+in that order, in the scope in which they are used.  If such
+variable is found, and if it contains a valid C<DBI> database
+handler, they will use it for performing the actual query.
+This allows one to write something like that, and expect the
+module to do the right thing:
+
+    my $dbh = DBI->connect(...);
+    my @r = db_fetch { users->name !~ /\@/ };
+
+Initially, the author did not recommend relying on this feature in the
+production code on a theory that it is `magical' and makes assumptions
+about names used outside of the module itself.
+The author recommended to always use the C<init()> subroutine.
+
+However, the experience of using the C<DBIx::Perlish> module
+in production environment
+has shown that the assumption about the name of the database handle
+is true in almost all cases
+in practice
+(but see L</Working with multiple database handles> below),
+and that the magical nature of the feature does not hinder,
+indeed helps writing code in a style that is easy to maintain.
+In fact, there is often B<less> of an action-at-a-distance effect when
+relying on the implicit C<$dbh> instead of using the C<init()> sub.
+
+
 =head3 db_fetch {}
 
 The C<db_fetch {}> function queries and returns data from
@@ -824,6 +861,13 @@ query subs.  Please see L</Compound queries' statements>
 for details.  The C<intersect()> can be exported via C<:all>
 import declaration.
 
+=head3 except()
+
+This is a helper sub which is meant to be used inside
+query subs.  Please see L</Compound queries' statements>
+for details.  The C<except()> can be exported via C<:all>
+import declaration.
+
 =head3 quirk()
 
 Unfortunately it is not always possible to generate an
@@ -863,49 +907,17 @@ it to.
 =back
 
 
-=head3 except()
-
-This is a helper sub which is meant to be used inside
-query subs.  Please see L</Compound queries' statements>
-for details.  The C<except()> can be exported via C<:all>
-import declaration.
-
-
 =head3 $SQL and @BIND_VALUES
 
 The C<DBIx::Perlish> module provides two global variables
 (not exported) to aid in debugging.
 The C<$DBIx::Perlish::SQL> variable contains the text of 
-the SQL which was most recently generated by the procedures above
-(except C<db_insert()>).
+the SQL which was generated during the most recent
+invocation of one of C<db_fetch {}>, C<db_update {}>,
+or C<db_delete {}>.
 The C<@DBIx::Perlish::BIND_VALUES> array contains the bind values
 to be used with the corresponding SQL code.
 
-=head3 Special treatment of the C<$dbh> variable
-
-If the procedural interface is used, and the user did not
-call C<init()> before issuing any of the C<db_fetch {}>,
-C<db_update {}>, C<db_delete {}> or C<db_insert {}>, those
-functions look for one special case before bailing out.
-
-Namely, they try to locate a variable C<my $dbh>, C<our $dbh>,
-or caller's package global C<$dbh>,
-in that order, in the scope in which they are used.  If such
-variable is found, and if it contains a valid C<DBI> database
-handler, they will use it for performing the actual query.
-This allows one to write something like that, and expect the
-module to do the right thing:
-
-    my $dbh = DBI->connect(...);
-    my @r = db_fetch { users->name !~ /\@/ };
-
-The author cannot recommend relying on this feature in the
-production code;  if in doubt, call C<init()> first
-and you won't be unpleasantly surprized.
-
-In order for this feature to be operational, the C<PadWalker>
-module must be installed.
-
 
 =head2 Query sub syntax
 
